<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>Anclar arriba</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>Mover al inicio</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eliminar de Favoritos</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>Añadir a Favoritos</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>Quitar del escritorio</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Enviar al escritorio</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Desanclar del muelle</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Anclar al muelle</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Quitar del arranque</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Añadir al arranque</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Usar un proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Desactivar escalado de pantalla</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>Encender</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>Modo pantalla completa</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>Uso frecuente</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>Modo ventana</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Mensajería</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Juegos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofimática</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desarrollo</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>¿Desea desinstalar «%1»?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>Instalado recientemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>Todas las aplicaciones</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Sin resultados</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>Ordenar libremente</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>Ordenar por categoría</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>Ordenar por nombre</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>Modo clasificación</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>Equipo</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>Centro de control</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Mensajería</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Juegos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofimática</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desarrollo</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>¿Desea desinstalar «%1»?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>